aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/Utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/core/Utils.h')
-rw-r--r--arm_compute/core/Utils.h16
1 files changed, 6 insertions, 10 deletions
diff --git a/arm_compute/core/Utils.h b/arm_compute/core/Utils.h
index 6ffab4b9ea..0ce2ee0161 100644
--- a/arm_compute/core/Utils.h
+++ b/arm_compute/core/Utils.h
@@ -853,21 +853,17 @@ PadStrideInfo calculate_same_pad(TensorShape input_shape, TensorShape weights_sh
/** Returns expected width and height of the deconvolution's output tensor.
*
* @param[in] in_width Width of input tensor (Number of columns)
* @param[in] in_height Height of input tensor (Number of rows)
* @param[in] kernel_width Kernel width.
* @param[in] kernel_height Kernel height.
* @param[in] padx X axis padding.
* @param[in] pady Y axis padding.
* @param[in] stride_x X axis input stride.
* @param[in] stride_y Y axis input stride.
*
* @return A pair with the new width in the first position and the new height in the second.
*/
std::pair<unsigned int, unsigned int> deconvolution_output_dimensions(unsigned int in_width, unsigned int in_height,
unsigned int kernel_width, unsigned int kernel_height,
- unsigned int padx, unsigned int pady,
- unsigned int stride_x, unsigned int stride_y);
+ const PadStrideInfo &pad_stride_info);
/** Returns expected width and height of output scaled tensor depending on dimensions rounding mode.
*
@@ -853,21 +853,17 @@ PadStrideInfo calculate_same_pad(TensorShape input_shape, TensorShape weights_sh
/** Returns expected width and height of the deconvolution's output tensor.
*
- * @param[in] in_width Width of input tensor (Number of columns)
- * @param[in] in_height Height of input tensor (Number of rows)
- * @param[in] kernel_width Kernel width.
- * @param[in] kernel_height Kernel height.
- * @param[in] padx X axis padding.
- * @param[in] pady Y axis padding.
- * @param[in] stride_x X axis input stride.
- * @param[in] stride_y Y axis input stride.
+ * @param[in] in_width Width of input tensor (Number of columns)
+ * @param[in] in_height Height of input tensor (Number of rows)
+ * @param[in] kernel_width Kernel width.
+ * @param[in] kernel_height Kernel height.
+ * @param[in] pad_stride_info Pad and stride information.
*
* @return A pair with the new width in the first position and the new height in the second.